@@ -10,6 +10,12 @@ log = logging.getLogger(__name__)
 
 @lru_cache(maxsize=1)
 def read_version():
+    """Attempts to read the version from the environment, returning 'NA' when it
+    fails.  It first looks for the existence of a VERSION file, then tries to
+    use git to obtain a tag.
+
+    :returns: A string describing the version.
+    """
     return _read_version_from_file() or _read_version_from_git() or "NA"
 
 
@@ -17,7 +23,7 @@ def _read_version_from_file():
     handle = None
     try:
         log.info("Reading version from file")
-        handle = open('VERSION', 'r')
+        handle = open("VERSION", "r")
         return handle.read().rstrip()
     except FileNotFoundError:
         return None
@@ -28,8 +34,11 @@ def _read_version_from_file():
 
 def _read_version_from_git():
     try:
-        return subprocess.run(['git', 'describe', '--always'], stdout=subprocess.PIPE)\
-                         .stdout.decode('utf-8').rstrip()
+        return (
+            subprocess.run(["git", "describe", "--always"], stdout=subprocess.PIPE)
+            .stdout.decode("utf-8")
+            .rstrip()
+        )
     except subprocess.SubprocessError:
         return None
     except FileNotFoundError:
